@@ -142,7 +142,7 @@ class MultiprocessDomparserResult():
         index = -1
         for output_html in output_htmls:
             index = index+1
-            soup = BeautifulSoup(output_html[0], features="html.parser")
+            soup = BeautifulSoup(output_html, features="html.parser")
             body = soup.body
             body_contents = str(body.find_all(recursive=False)[0])
             wrapped_result = f"""
